Differentiation
---------------

Numerical derivatives (``diff``, ``diffs``)
...........................................

.. autofunction:: mpmath.diff
.. autofunction:: mpmath.diffs

Composition of derivatives (``diffs_prod``, ``diffs_exp``)
..........................................................

.. autofunction:: mpmath.diffs_prod
.. autofunction:: mpmath.diffs_exp

Fractional derivatives / differintegration (``differint``)
............................................................

.. autofunction:: mpmath.differint
